run_from_env

Function run_from_env 

pub fn run_from_env() -> Result<(), CliError>
Run the CLI from the current process arguments.

Errors

Returns a bounded CliError when arguments are invalid, the icp process fails, the canister rejects the request, or output cannot be rendered.